@@ -463,13 +463,13 @@ gnome_print_dialog_get_range (GnomePrintDialog *gpd)
 	r = gtk_object_get_data (GTK_OBJECT (f), "range");
 	g_return_val_if_fail (r != NULL, 0);
 
-	b = gtk_object_get_data (GTK_OBJECT (b), "current");
+	b = gtk_object_get_data (GTK_OBJECT (r), "current");
 	if (b && GTK_IS_TOGGLE_BUTTON (b) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (b))) return GNOME_PRINT_RANGE_CURRENT;
-	b = gtk_object_get_data (GTK_OBJECT (b), "all");
+	b = gtk_object_get_data (GTK_OBJECT (r), "all");
 	if (b && GTK_IS_TOGGLE_BUTTON (b) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (b))) return GNOME_PRINT_RANGE_ALL;
-	b = gtk_object_get_data (GTK_OBJECT (b), "range");
+	b = gtk_object_get_data (GTK_OBJECT (r), "range");
 	if (b && GTK_IS_TOGGLE_BUTTON (b) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (b))) return GNOME_PRINT_RANGE_RANGE;
-	b = gtk_object_get_data (GTK_OBJECT (b), "selection");
+	b = gtk_object_get_data (GTK_OBJECT (r), "selection");
 	if (b && GTK_IS_TOGGLE_BUTTON (b) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (b))) return GNOME_PRINT_RANGE_SELECTION;
 
 	return 0;
