@@ -2758,48 +2758,6 @@ gnome_paper_selector_get_bottom_margin(GnomePaperSelector *gspaper);
 }
 #endif
 
-
-#ifdef PAGELAYOUT_TEST
-
-void
-changed_signal(GnomePaperSelector *self)
-{
-  g_message("changed");
-}
-void
-fittopage_signal(GnomePaperSelector *self)
-{
-  g_message("fit to page");
-}
-
-void
-main(int argc, char **argv)
-{
-  GtkWidget *win, *ps;
-
-  gtk_init(&argc, &argv);
-
-  win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title(GTK_WINDOW(win), _("Page Setup"));
-  gtk_signal_connect(GTK_OBJECT(win), "destroy",
-		     GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
-
-  ps = gnome_paper_selector_new();
-  gtk_container_set_border_width(GTK_CONTAINER(ps), 5);
-  gtk_container_add(GTK_CONTAINER(win), ps);
-  gtk_widget_show(ps);
-
-  gtk_signal_connect(GTK_OBJECT(ps), "changed",
-		     GTK_SIGNAL_FUNC(changed_signal), NULL);
-  gtk_signal_connect(GTK_OBJECT(ps), "fittopage",
-		     GTK_SIGNAL_FUNC(fittopage_signal), NULL);
-
-  gtk_widget_show(win);
-  gtk_main();
-}
-
-#endif
-
 #endif /* The whole thing */
 
 
